@@ -32,6 +32,7 @@ import org.apache.sedona.common.geometryObjects.Circle;
 import org.apache.sedona.common.sphere.Spheroid;
 import org.apache.sedona.common.subDivide.GeometrySubDivider;
 import org.apache.sedona.common.utils.*;
+import org.locationtech.jts.algorithm.Angle;
 import org.locationtech.jts.algorithm.MinimumBoundingCircle;
 import org.locationtech.jts.algorithm.Orientation;
 import org.locationtech.jts.algorithm.construct.LargestEmptyCircle;
@@ -59,6 +60,7 @@ import org.locationtech.jts.operation.valid.IsValidOp;
 import org.locationtech.jts.operation.valid.TopologyValidationError;
 import org.locationtech.jts.precision.GeometryPrecisionReducer;
 import org.locationtech.jts.precision.MinimumClearance;
+import org.locationtech.jts.simplify.DouglasPeuckerSimplifier;
 import org.locationtech.jts.simplify.PolygonHullSimplifier;
 import org.locationtech.jts.simplify.TopologyPreservingSimplifier;
 import org.locationtech.jts.simplify.VWSimplifier;
@@ -455,10 +457,28 @@ public class Functions {
     return new Distance3DOp(left, right).distance();
   }
 
-  public static double length(Geometry geometry) {
+  public static double baseLength(Geometry geometry) {
     return geometry.getLength();
   }
 
+  public static double length(Geometry geometry) {
+    String geomType = geometry.getGeometryType();
+    if (geomType.equalsIgnoreCase(Geometry.TYPENAME_LINESTRING)
+        || geomType.equalsIgnoreCase(Geometry.TYPENAME_POINT)
+        || geomType.equalsIgnoreCase(Geometry.TYPENAME_MULTIPOINT)
+        || geomType.equalsIgnoreCase(Geometry.TYPENAME_MULTILINESTRING)) {
+      return baseLength(geometry);
+    } else if (geomType.equalsIgnoreCase(Geometry.TYPENAME_GEOMETRYCOLLECTION)) {
+      double length = 0;
+      for (int i = 0; i < geometry.getNumGeometries(); i++) {
+        length += length(geometry.getGeometryN(i));
+      }
+      return length;
+    } else {
+      return 0;
+    }
+  }
+
   public static Geometry normalize(Geometry geometry) {
     geometry.normalize();
     return geometry;
@@ -873,6 +893,14 @@ public class Functions {
     return null;
   }
 
+  public static Geometry removeRepeatedPoints(Geometry geom, double tolerance) {
+    return GeometryDuplicateCoordinateRemover.process(geom, tolerance);
+  }
+
+  public static Geometry removeRepeatedPoints(Geometry geom) {
+    return removeRepeatedPoints(geom, 0);
+  }
+
   public static Geometry setPoint(Geometry linestring, int position, Geometry point) {
     if (linestring instanceof LineString) {
       List<Coordinate> coordinates = new ArrayList<>(Arrays.asList(linestring.getCoordinates()));
@@ -1040,7 +1068,7 @@ public class Functions {
     // All non-polygonal geometries use LargestEmptyCircle
     if (!geometry.getClass().getSimpleName().equals("Polygon")
         && !geometry.getClass().getSimpleName().equals("MultiPolygon")) {
-      LargestEmptyCircle largestEmptyCircle = new LargestEmptyCircle(geometry, tolerance);
+      LargestEmptyCircle largestEmptyCircle = new LargestEmptyCircle(geometry, null, tolerance);
       center = largestEmptyCircle.getCenter();
       nearest = largestEmptyCircle.getRadiusPoint();
       radius = largestEmptyCircle.getRadiusLine().getLength();
@@ -1084,6 +1112,46 @@ public class Functions {
     return geom.getFactory().createPoint(interPoint);
   }
 
+  public static double perimeter(Geometry geometry, boolean use_spheroid, boolean lenient) {
+    if (use_spheroid && geometry.getSRID() != 4326) {
+      if (!lenient) {
+        throw new IllegalArgumentException(
+            "For spheroidal perimeter calculations, the input geometry must be in the WGS84 CRS (SRID 4326).");
+      }
+    }
+
+    String geomType = geometry.getGeometryType();
+    if (geomType.equalsIgnoreCase(Geometry.TYPENAME_POLYGON)) {
+      return calculateLength(geometry, use_spheroid);
+    } else if (geomType.equalsIgnoreCase(Geometry.TYPENAME_MULTIPOLYGON)) {
+      return calculateLength(geometry, use_spheroid);
+    } else if (geomType.equalsIgnoreCase(Geometry.TYPENAME_GEOMETRYCOLLECTION)) {
+      double perimeter = 0;
+      for (int i = 0; i < geometry.getNumGeometries(); i++) {
+        perimeter += perimeter(geometry.getGeometryN(i), use_spheroid, lenient);
+      }
+      return perimeter;
+    } else {
+      return 0;
+    }
+  }
+
+  private static double calculateLength(Geometry geometry, boolean use_spheroid) {
+    if (use_spheroid) {
+      return Spheroid.baseLength(geometry);
+    } else {
+      return baseLength(geometry);
+    }
+  }
+
+  public static double perimeter(Geometry geometry, boolean use_spheroid) {
+    return perimeter(geometry, use_spheroid, true);
+  }
+
+  public static double perimeter(Geometry geometry) {
+    return perimeter(geometry, false);
+  }
+
   /**
    * Forces a Polygon/MultiPolygon to use clockwise orientation for the exterior ring and a
    * counter-clockwise for the interior ring(s).
@@ -1345,6 +1413,45 @@ public class Functions {
     return dimension;
   }
 
+  public static Geometry project(Geometry point, double distance, double azimuth, boolean lenient) {
+    if (!point.getClass().getSimpleName().equals("Point")) {
+      if (lenient) {
+        return point.getFactory().createPoint();
+      } else {
+        throw new IllegalArgumentException(
+            String.format(
+                "Input geometry is %s. It should be a Point type geometry",
+                point.getClass().getSimpleName()));
+      }
+    }
+
+    // Normalize azimuth if it is out of (-360, 360) range
+    // by calculating the number of orbits and subtracting it
+    int orbit = (int) Math.floor(azimuth / Angle.PI_TIMES_2);
+    azimuth -= Angle.PI_TIMES_2 * orbit;
+    // Convert azimuth to conventional slope
+    double slope = Angle.PI_TIMES_2 - azimuth + Angle.PI_OVER_2;
+    if (slope > Angle.PI_TIMES_2) slope -= Angle.PI_TIMES_2;
+    if (slope < -Angle.PI_TIMES_2) slope += Angle.PI_TIMES_2;
+
+    Coordinate projectedCoordinate = Angle.project(point.getCoordinate(), slope, distance);
+
+    if (Functions.hasZ(point)) {
+      projectedCoordinate.setZ(point.getCoordinate().getZ());
+    }
+
+    if (Functions.hasM(point)) {
+      CoordinateXYZM projectedCoordinateM = new CoordinateXYZM(projectedCoordinate);
+      projectedCoordinateM.setM(point.getCoordinate().getM());
+      return point.getFactory().createPoint(projectedCoordinateM);
+    }
+    return point.getFactory().createPoint(projectedCoordinate);
+  }
+
+  public static Geometry project(Geometry point, double distance, double azimuth) {
+    return project(point, distance, azimuth, false);
+  }
+
   /**
    * get the coordinates of a geometry and transform to Google s2 cell id
    *
@@ -1495,6 +1602,10 @@ public class Functions {
     return polygons.toArray(new Polygon[0]);
   }
 
+  public static Geometry simplify(Geometry geom, double distanceTolerance) {
+    return DouglasPeuckerSimplifier.simplify(geom, distanceTolerance);
+  }
+
   // create static function named simplifyPreserveTopology
   public static Geometry simplifyPreserveTopology(Geometry geometry, double distanceTolerance) {
     return TopologyPreservingSimplifier.simplify(geometry, distanceTolerance);
@@ -2213,6 +2324,45 @@ public class Functions {
     return geometry.getFactory().createMultiPointFromCoords(coordinates);
   }
 
+  public static Geometry scale(Geometry geometry, double scaleX, double scaleY) {
+    return scaleGeom(geometry, Constructors.point(scaleX, scaleY));
+  }
+
+  public static Geometry scaleGeom(Geometry geometry, Geometry factor) {
+    return scaleGeom(geometry, factor, null);
+  }
+
+  public static Geometry scaleGeom(Geometry geometry, Geometry factor, Geometry origin) {
+    if (geometry == null || factor == null || geometry.isEmpty() || factor.isEmpty()) {
+      return geometry;
+    }
+
+    if (!factor.getGeometryType().equalsIgnoreCase(Geometry.TYPENAME_POINT)) {
+      throw new IllegalArgumentException("Scale factor geometry should be a Point type.");
+    }
+
+    Geometry resultGeom = null;
+    AffineTransformation scaleInstance = null;
+    Coordinate factorCoordinate = factor.getCoordinate();
+
+    if (origin == null || origin.isEmpty()) {
+      scaleInstance =
+          AffineTransformation.scaleInstance(factorCoordinate.getX(), factorCoordinate.getY());
+      resultGeom = scaleInstance.transform(geometry);
+    } else {
+      Coordinate falseOrigin = origin.getCoordinate();
+      scaleInstance =
+          AffineTransformation.scaleInstance(
+              factorCoordinate.getX(),
+              factorCoordinate.getY(),
+              falseOrigin.getX(),
+              falseOrigin.getY());
+      resultGeom = scaleInstance.transform(geometry);
+    }
+
+    return resultGeom;
+  }
+
   public static Geometry rotateX(Geometry geometry, double angle) {
     if (GeomUtils.isAnyGeomEmpty(geometry)) {
       return geometry;
@@ -2222,6 +2372,15 @@ public class Functions {
     return affine(geometry, 1, 0, 0, 0, cosAngle, -sinAngle, 0, sinAngle, cosAngle, 0, 0, 0);
   }
 
+  public static Geometry rotateY(Geometry geometry, double angle) {
+    if (GeomUtils.isAnyGeomEmpty(geometry)) {
+      return geometry;
+    }
+    double sinAngle = Math.sin(angle);
+    double cosAngle = Math.cos(angle);
+    return affine(geometry, cosAngle, 0, sinAngle, 0, 1, 0, -sinAngle, 0, cosAngle, 0, 0, 0);
+  }
+
   /**
    * Rotates a geometry by a given angle in radians.
    *
@@ -2276,4 +2435,57 @@ public class Functions {
     AffineTransformation rotation = AffineTransformation.rotationInstance(angle, originX, originY);
     return rotation.transform(geometry);
   }
+
+  /**
+   * This function returns the m coordinate of the closest point in a LineString to the specified
+   * Point.
+   *
+   * @param geom1 The LineString (with or without M values) to be evaluated.
+   * @param geom2 The Point object to find the closest point to.
+   * @return The interpolated M value of the closest point on the LineString.
+   */
+  public static double interpolatePoint(Geometry geom1, Geometry geom2) {
+    if (!(Geometry.TYPENAME_LINESTRING.equalsIgnoreCase(geom1.getGeometryType()))) {
+      throw new IllegalArgumentException(
+          String.format(
+              "First argument is of type %s, should be a LineString.", geom1.getGeometryType()));
+    }
+    if (!(Geometry.TYPENAME_POINT.equalsIgnoreCase(geom2.getGeometryType()))) {
+      throw new IllegalArgumentException(
+          String.format(
+              "Second argument is of type %s, should be a Point.", geom2.getGeometryType()));
+    }
+    if (Float.isNaN((float) geom1.getCoordinate().getM())) {
+      throw new IllegalArgumentException("The given linestring does not have a measure value.");
+    }
+
+    if (geom1.getSRID() != geom2.getSRID()) {
+      throw new IllegalArgumentException(
+          String.format(
+              "The Line has SRID %d and Point has SRID %d. The Line and Point should be in the same SRID.",
+              geom1.getSRID(), geom2.getSRID()));
+    }
+
+    LineString line = (LineString) geom1;
+    Point point = (Point) geom2;
+
+    // Find the closest point on the line to the input point
+    Coordinate closestPoint = DistanceOp.nearestPoints(line, point)[0];
+
+    // Use LengthIndexedLine to extract the index at the closest point
+    LengthIndexedLine indexedLine = new LengthIndexedLine(line);
+    double index = indexedLine.indexOf(closestPoint);
+
+    // Extract the point at that index and compute its length fraction
+    double totalLength = indexedLine.getEndIndex();
+    double fractionAlongLine = index / totalLength;
+
+    // Get the start and end coordinates of the line
+    Geometry start = line.getStartPoint();
+    Geometry end = line.getEndPoint();
+
+    // Interpolate the M value
+    return fractionAlongLine * (end.getCoordinate().getM() - start.getCoordinate().getM())
+        + start.getCoordinate().getM();
+  }
 }
