@@ -29,6 +29,7 @@ import org.apache.commons.lang3.tuple.Pair;
 import org.apache.sedona.common.utils.RasterUtils;
 import org.geotools.coverage.GridSampleDimension;
 import org.geotools.coverage.grid.GridCoverage2D;
+import org.geotools.coverage.processing.CannotCropException;
 import org.geotools.coverage.processing.operation.Crop;
 import org.locationtech.jts.geom.Geometry;
 import org.opengis.parameter.ParameterValueGroup;
@@ -273,10 +274,17 @@ public class RasterBandEditors {
    * @param geometry Specify ROI
    * @param noDataValue no-Data value for empty cells
    * @param crop Specifies to keep the original extent or not
+   * @param lenient Return null if the raster and geometry do not intersect when set to true,
+   *     otherwise will throw an exception
    * @return A clip Raster with defined ROI by the geometry
    */
   public static GridCoverage2D clip(
-      GridCoverage2D raster, int band, Geometry geometry, double noDataValue, boolean crop)
+      GridCoverage2D raster,
+      int band,
+      Geometry geometry,
+      double noDataValue,
+      boolean crop,
+      boolean lenient)
       throws FactoryException, TransformException {
 
     // Selecting the band from original raster
@@ -296,7 +304,16 @@ public class RasterBandEditors {
     parameters.parameter(Crop.PARAMNAME_DEST_NODATA).setValue(new double[] {noDataValue});
     parameters.parameter(Crop.PARAMNAME_ROI).setValue(geometry);
 
-    GridCoverage2D newRaster = (GridCoverage2D) cropObject.doOperation(parameters, null);
+    GridCoverage2D newRaster;
+    try {
+      newRaster = (GridCoverage2D) cropObject.doOperation(parameters, null);
+    } catch (CannotCropException e) {
+      if (lenient) {
+        return null;
+      } else {
+        throw e;
+      }
+    }
 
     if (!crop) {
       double[] metadataOriginal = RasterAccessors.metadata(raster);
@@ -383,6 +400,22 @@ public class RasterBandEditors {
     return newRaster;
   }
 
+  /**
+   * Return a clipped raster with the specified ROI by the geometry
+   *
+   * @param raster Raster to clip
+   * @param band Band number to perform clipping
+   * @param geometry Specify ROI
+   * @param noDataValue no-Data value for empty cells
+   * @param crop Specifies to keep the original extent or not
+   * @return A clip Raster with defined ROI by the geometry
+   */
+  public static GridCoverage2D clip(
+      GridCoverage2D raster, int band, Geometry geometry, double noDataValue, boolean crop)
+      throws FactoryException, TransformException {
+    return clip(raster, band, geometry, noDataValue, crop, true);
+  }
+
   /**
    * Return a clipped raster with the specified ROI by the geometry.
    *
