@@ -36,6 +36,7 @@ public class Catalog {
       new Constructors.ST_PointFromWKB(),
       new Constructors.ST_LineFromWKB(),
       new Constructors.ST_LinestringFromWKB(),
+      new Constructors.ST_MakeEnvelope(),
       new Constructors.ST_MakePoint(),
       new Constructors.ST_MakePointM(),
       new Constructors.ST_LineStringFromText(),
@@ -87,6 +88,7 @@ public class Catalog {
       new Functions.ST_DelaunayTriangles(),
       new Functions.ST_EndPoint(),
       new Functions.ST_GeometryType(),
+      new Functions.ST_InterpolatePoint(),
       new Functions.ST_Intersection(),
       new Functions.ST_Length(),
       new Functions.ST_Length2D(),
@@ -98,11 +100,15 @@ public class Catalog {
       new FunctionsGeoTools.ST_Transform(),
       new Functions.ST_FlipCoordinates(),
       new Functions.ST_GeoHash(),
+      new Functions.ST_Perimeter(),
       new Functions.ST_PointOnSurface(),
+      new Functions.ST_Scale(),
+      new Functions.ST_ScaleGeom(),
       new Functions.ST_ReducePrecision(),
       new Functions.ST_Reverse(),
       new Functions.ST_Rotate(),
       new Functions.ST_RotateX(),
+      new Functions.ST_RotateY(),
       new Functions.ST_GeometryN(),
       new Functions.ST_InteriorRingN(),
       new Functions.ST_PointN(),
@@ -145,6 +151,7 @@ public class Catalog {
       new Functions.ST_AddMeasure(),
       new Functions.ST_AddPoint(),
       new Functions.ST_RemovePoint(),
+      new Functions.ST_RemoveRepeatedPoints(),
       new Functions.ST_SetPoint(),
       new Functions.ST_LineFromMultiPoint(),
       new Functions.ST_LineMerge(),
@@ -158,6 +165,7 @@ public class Catalog {
       new Functions.ST_Points(),
       new Functions.ST_Polygon(),
       new Functions.ST_Polygonize(),
+      new Functions.ST_Project(),
       new Functions.ST_MakePolygon(),
       new Functions.ST_MakeValid(),
       new Functions.ST_MaxDistance(),
@@ -168,6 +176,7 @@ public class Catalog {
       new Functions.ST_Multi(),
       new Functions.ST_StartPoint(),
       new Functions.ST_ShiftLongitude(),
+      new Functions.ST_Simplify(),
       new Functions.ST_SimplifyPreserveTopology(),
       new Functions.ST_SimplifyVW(),
       new Functions.ST_SimplifyPolygonHull(),
