@@ -28,4 +28,5 @@ class GeoDataReader(metaclass=MultipleMeta):
     @abc.abstractmethod
     def readToGeometryRDD(cls, *args, **kwargs):
         raise NotImplementedError(
-            f"Instance of the class {cls.__class__.__name__} has to implement method readToGeometryRDD")
+            f"Instance of the class {cls.__class__.__name__} has to implement method readToGeometryRDD"
+        )
