@@ -29,9 +29,9 @@ class GeometryParser(ABC):
         raise NotImplementedError
 
     @classmethod
-    def serialize(cls, obj: BaseGeometry, binary_buffer: 'BinaryBuffer'):
+    def serialize(cls, obj: BaseGeometry, binary_buffer: "BinaryBuffer"):
         raise NotImplementedError("Parser has to implement serialize method")
 
     @classmethod
-    def deserialize(cls, bin_parser: 'BinaryParser') -> BaseGeometry:
+    def deserialize(cls, bin_parser: "BinaryParser") -> BaseGeometry:
         raise NotImplementedError("Parser has to implement deserialize method")
