@@ -15,9 +15,10 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from sedona.core.geom.envelope import Envelope
 from tests.test_base import TestBase
 
+from sedona.core.geom.envelope import Envelope
+
 
 class TestGeomPrimitives(TestBase):
 
@@ -25,4 +26,6 @@ class TestGeomPrimitives(TestBase):
         envelope = Envelope(0.0, 5.0, 0.0, 5.0)
         jvm_instance = envelope.create_jvm_instance(self.spark.sparkContext._jvm)
         envelope_area = jvm_instance.getArea()
-        assert envelope_area == 25.0, f"Expected area to be equal 25 but {envelope_area} was found"
+        assert (
+            envelope_area == 25.0
+        ), f"Expected area to be equal 25 but {envelope_area} was found"
