@@ -17,16 +17,16 @@
 
 import os
 
-from shapely.geometry import Point
 from pyspark import StorageLevel
-
-from sedona.core.SpatialRDD import PointRDD, CircleRDD, PolygonRDD
-from sedona.core.enums import FileDataSplitter, IndexType, GridType
-from sedona.core.geom.envelope import Envelope
-from sedona.core.spatialOperator import RangeQuery, JoinQuery, KNNQuery
+from shapely.geometry import Point
 from tests.test_base import TestBase
 from tests.tools import tests_resource
 
+from sedona.core.enums import FileDataSplitter, GridType, IndexType
+from sedona.core.geom.envelope import Envelope
+from sedona.core.spatialOperator import JoinQuery, KNNQuery, RangeQuery
+from sedona.core.SpatialRDD import CircleRDD, PointRDD, PolygonRDD
+
 point_rdd_input_location = os.path.join(tests_resource, "arealm-small.csv")
 
 point_rdd_splitter = FileDataSplitter.CSV
@@ -52,32 +52,55 @@ class TestScalaExample(TestBase):
 
     def test_spatial_range_query(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
         )
         object_rdd.rawJvmSpatialRDD.persist(StorageLevel.MEMORY_ONLY)
         for _ in range(each_query_loop_times):
-            result_size = RangeQuery.SpatialRangeQuery(object_rdd, range_query_window, False, False).count()
+            result_size = RangeQuery.SpatialRangeQuery(
+                object_rdd, range_query_window, False, False
+            ).count()
 
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
         )
         object_rdd.rawJvmSpatialRDD.persist(StorageLevel.MEMORY_ONLY)
         for _ in range(each_query_loop_times):
-            result_size = RangeQuery.SpatialRangeQuery(object_rdd, range_query_window, False, False).count()
+            result_size = RangeQuery.SpatialRangeQuery(
+                object_rdd, range_query_window, False, False
+            ).count()
 
     def test_spatial_range_query_using_index(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
         object_rdd.buildIndex(point_rdd_index_type, False)
         object_rdd.indexedRawRDD.persist(StorageLevel.MEMORY_ONLY)
         assert object_rdd.indexedRawRDD.is_cached
 
         for _ in range(each_query_loop_times):
-            result_size = RangeQuery.SpatialRangeQuery(object_rdd, range_query_window, False, True).count
+            result_size = RangeQuery.SpatialRangeQuery(
+                object_rdd, range_query_window, False, True
+            ).count
 
     def test_spatial_knn_query(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
         )
         object_rdd.rawJvmSpatialRDD.persist(StorageLevel.MEMORY_ONLY)
 
@@ -86,7 +109,11 @@ class TestScalaExample(TestBase):
 
     def test_spatial_knn_query_using_index(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
         )
         object_rdd.buildIndex(point_rdd_index_type, False)
         object_rdd.indexedRawRDD.persist(StorageLevel.MEMORY_ONLY)
@@ -96,11 +123,20 @@ class TestScalaExample(TestBase):
 
     def test_spatial_join_query(self):
         query_window_rdd = PolygonRDD(
-            self.sc, polygon_rdd_input_location, polygon_rdd_start_offset, polygon_rdd_end_offset,
-            polygon_rdd_splitter, True
+            self.sc,
+            polygon_rdd_input_location,
+            polygon_rdd_start_offset,
+            polygon_rdd_end_offset,
+            polygon_rdd_splitter,
+            True,
         )
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
 
         object_rdd.spatialPartitioning(join_query_partitioning_type)
         query_window_rdd.spatialPartitioning(object_rdd.getPartitioner())
@@ -109,15 +145,25 @@ class TestScalaExample(TestBase):
         query_window_rdd.jvmSpatialPartitionedRDD.persist(StorageLevel.MEMORY_ONLY)
 
         for _ in range(each_query_loop_times):
-            result_size = JoinQuery.SpatialJoinQuery(object_rdd, query_window_rdd, False, True).count()
+            result_size = JoinQuery.SpatialJoinQuery(
+                object_rdd, query_window_rdd, False, True
+            ).count()
 
     def test_spatial_join_using_index(self):
         query_window_rdd = PolygonRDD(
-            self.sc, polygon_rdd_input_location, polygon_rdd_start_offset,
-            polygon_rdd_end_offset, polygon_rdd_splitter, True
+            self.sc,
+            polygon_rdd_input_location,
+            polygon_rdd_start_offset,
+            polygon_rdd_end_offset,
+            polygon_rdd_splitter,
+            True,
         )
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
         )
 
         object_rdd.spatialPartitioning(join_query_partitioning_type)
@@ -135,7 +181,12 @@ class TestScalaExample(TestBase):
 
     def test_distance_join_query(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
         query_window_rdd = CircleRDD(object_rdd, 0.1)
 
         object_rdd.spatialPartitioning(GridType.QUADTREE)
@@ -147,11 +198,18 @@ class TestScalaExample(TestBase):
         query_window_rdd.spatialPartitionedRDD.persist(StorageLevel.MEMORY_ONLY)
 
         for _ in range(each_query_loop_times):
-            result_size = JoinQuery.DistanceJoinQuery(object_rdd, query_window_rdd, False, True).count()
+            result_size = JoinQuery.DistanceJoinQuery(
+                object_rdd, query_window_rdd, False, True
+            ).count()
 
     def test_distance_join_using_index(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
 
         query_window_rdd = CircleRDD(object_rdd, 0.1)
 
@@ -166,11 +224,18 @@ class TestScalaExample(TestBase):
         assert query_window_rdd.spatialPartitionedRDD.is_cached
 
         for _ in range(each_query_loop_times):
-            result_size = JoinQuery.DistanceJoinQuery(object_rdd, query_window_rdd, True, True).count()
+            result_size = JoinQuery.DistanceJoinQuery(
+                object_rdd, query_window_rdd, True, True
+            ).count()
 
     def test_indexed_rdd_assignment(self):
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
         query_window_rdd = CircleRDD(object_rdd, 0.1)
         object_rdd.analyze()
         object_rdd.spatialPartitioning(GridType.QUADTREE)
@@ -189,11 +254,18 @@ class TestScalaExample(TestBase):
 
         start = time.time()
         for _ in range(each_query_loop_times):
-            result_size = JoinQuery.DistanceJoinQuery(object_rdd, query_window_rdd, True, True).count()
+            result_size = JoinQuery.DistanceJoinQuery(
+                object_rdd, query_window_rdd, True, True
+            ).count()
         diff = time.time() - start
 
         object_rdd = PointRDD(
-            self.sc, point_rdd_input_location, point_rdd_offset, point_rdd_splitter, True)
+            self.sc,
+            point_rdd_input_location,
+            point_rdd_offset,
+            point_rdd_splitter,
+            True,
+        )
         query_window_rdd = CircleRDD(object_rdd, 0.1)
 
         object_rdd.analyze()
@@ -206,4 +278,6 @@ class TestScalaExample(TestBase):
 
         start1 = time.time()
         for _ in range(each_query_loop_times):
-            result_size = JoinQuery.DistanceJoinQuery(object_rdd, query_window_rdd, True, True).count()
+            result_size = JoinQuery.DistanceJoinQuery(
+                object_rdd, query_window_rdd, True, True
+            ).count()
