@@ -807,6 +807,21 @@ public class UDFs {
     return GeometrySerde.serialize(Functions.pointN(GeometrySerde.deserialize(geometry), n));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry"})
+  public static double ST_Perimeter(byte[] geometry) {
+    return Functions.perimeter(GeometrySerde.deserialize(geometry));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "use_spheroid"})
+  public static double ST_Perimeter(byte[] geometry, boolean use_spheroid) {
+    return Functions.perimeter(GeometrySerde.deserialize(geometry), use_spheroid);
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "use_spheroid", "lenient"})
+  public static double ST_Perimeter(byte[] geometry, boolean use_spheroid, boolean lenient) {
+    return Functions.perimeter(GeometrySerde.deserialize(geometry), use_spheroid, lenient);
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry"})
   public static byte[] ST_PointOnSurface(byte[] geometry) {
     return GeometrySerde.serialize(Functions.pointOnSurface(GeometrySerde.deserialize(geometry)));
@@ -873,6 +888,29 @@ public class UDFs {
     return GeometrySerde.serialize(Constructors.polygonFromEnvelope(minX, minY, maxX, maxY));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"point", "distance", "azimuth"})
+  public static byte[] ST_Project(byte[] point, double distance, double azimuth) {
+    return GeometrySerde.serialize(
+        Functions.project(GeometrySerde.deserialize(point), distance, azimuth));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"point", "distance", "azimuth", "lenient"})
+  public static byte[] ST_Project(byte[] point, double distance, double azimuth, boolean lenient) {
+    return GeometrySerde.serialize(
+        Functions.project(GeometrySerde.deserialize(point), distance, azimuth, lenient));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"minX", "minY", "maxX", "maxY"})
+  public static byte[] ST_MakeEnvelope(double minX, double minY, double maxX, double maxY) {
+    return GeometrySerde.serialize(Constructors.makeEnvelope(minX, minY, maxX, maxY));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"minX", "minY", "maxX", "maxY", "srid"})
+  public static byte[] ST_MakeEnvelope(
+      double minX, double minY, double maxX, double maxY, int srid) {
+    return GeometrySerde.serialize(Constructors.makeEnvelope(minX, minY, maxX, maxY, srid));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geomString", "delimiter"})
   public static byte[] ST_PolygonFromText(String geomString, String geomFormat) {
     return GeometrySerde.serialize(Constructors.polygonFromText(geomString, geomFormat));
@@ -901,6 +939,17 @@ public class UDFs {
         Functions.removePoint(GeometrySerde.deserialize(linestring), position));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geom"})
+  public static byte[] ST_RemoveRepeatedPoints(byte[] geom) {
+    return GeometrySerde.serialize(Functions.removeRepeatedPoints(GeometrySerde.deserialize(geom)));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geom", "tolerance"})
+  public static byte[] ST_RemoveRepeatedPoints(byte[] geom, double tolerance) {
+    return GeometrySerde.serialize(
+        Functions.removeRepeatedPoints(GeometrySerde.deserialize(geom), tolerance));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry"})
   public static byte[] ST_Reverse(byte[] geometry) {
     return GeometrySerde.serialize(Functions.reverse(GeometrySerde.deserialize(geometry)));
@@ -933,6 +982,12 @@ public class UDFs {
     return GeometrySerde.serialize(Functions.setSRID(GeometrySerde.deserialize(geometry), srid));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "distanceTolerance"})
+  public static byte[] ST_Simplify(byte[] geometry, double distanceTolerance) {
+    return GeometrySerde.serialize(
+        Functions.simplify(GeometrySerde.deserialize(geometry), distanceTolerance));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry", "distanceTolerance"})
   public static byte[] ST_SimplifyPreserveTopology(byte[] geometry, double distanceTolerance) {
     return GeometrySerde.serialize(
@@ -1250,11 +1305,38 @@ public class UDFs {
         Functions.translate(GeometrySerde.deserialize(geom), deltaX, deltaY, deltaZ));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "scaleX", "scaleY"})
+  public static byte[] ST_Scale(byte[] geometry, double scaleX, double scaleY) {
+    return GeometrySerde.serialize(
+        Functions.scale(GeometrySerde.deserialize(geometry), scaleX, scaleY));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "factor", "origin"})
+  public static byte[] ST_ScaleGeom(byte[] geometry, byte[] factor, byte[] origin) {
+    return GeometrySerde.serialize(
+        Functions.scaleGeom(
+            GeometrySerde.deserialize(geometry),
+            GeometrySerde.deserialize(factor),
+            GeometrySerde.deserialize(origin)));
+  }
+
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "factor"})
+  public static byte[] ST_ScaleGeom(byte[] geometry, byte[] factor) {
+    return GeometrySerde.serialize(
+        Functions.scaleGeom(
+            GeometrySerde.deserialize(geometry), GeometrySerde.deserialize(factor)));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geometry", "angle"})
   public static byte[] ST_RotateX(byte[] geometry, double angle) {
     return GeometrySerde.serialize(Functions.rotateX(GeometrySerde.deserialize(geometry), angle));
   }
 
+  @UDFAnnotations.ParamMeta(argNames = {"geometry", "angle"})
+  public static byte[] ST_RotateY(byte[] geometry, double angle) {
+    return GeometrySerde.serialize(Functions.rotateY(GeometrySerde.deserialize(geometry), angle));
+  }
+
   @UDFAnnotations.ParamMeta(argNames = {"geom", "angle"})
   public static byte[] ST_Rotate(byte[] geom, double angle) {
     return GeometrySerde.serialize(Functions.rotate(GeometrySerde.deserialize(geom), angle));
