@@ -939,6 +939,30 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.pointN(GeometrySerde.deserGeoJson(geometry), n));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry"},
+      argTypes = {"Geometry"},
+      returnTypes = "double")
+  public static double ST_Perimeter(String geometry) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "use_spheroid"},
+      argTypes = {"Geometry", "boolean"},
+      returnTypes = "double")
+  public static double ST_Perimeter(String geometry, boolean use_spheroid) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry), use_spheroid);
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "use_spheroid", "lenient"},
+      argTypes = {"Geometry", "boolean", "boolean"},
+      returnTypes = "double")
+  public static double ST_Perimeter(String geometry, boolean use_spheroid, boolean lenient) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry), use_spheroid, lenient);
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry"},
       argTypes = {"Geometry"},
@@ -972,6 +996,24 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.polygonize(GeometrySerde.deserGeoJson(geometry)));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"point", "distance", "azimuth"},
+      argTypes = {"Geometry", "double", "double"},
+      returnTypes = "Geometry")
+  public static String ST_Project(String point, double distance, double azimuth) {
+    return GeometrySerde.serGeoJson(
+        Functions.project(GeometrySerde.deserGeoJson(point), distance, azimuth));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"point", "distance", "azimuth", "lenient"},
+      argTypes = {"Geometry", "double", "double", "boolean"},
+      returnTypes = "Geometry")
+  public static String ST_Project(String point, double distance, double azimuth, boolean lenient) {
+    return GeometrySerde.serGeoJson(
+        Functions.project(GeometrySerde.deserGeoJson(point), distance, azimuth, lenient));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry", "precisionScale"},
       argTypes = {"Geometry", "int"},
@@ -1007,6 +1049,24 @@ public class UDFsV2 {
         Functions.removePoint(GeometrySerde.deserGeoJson(linestring), position));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geom"},
+      argTypes = {"Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_RemoveRepeatedPoints(String geom) {
+    return GeometrySerde.serGeoJson(
+        Functions.removeRepeatedPoints(GeometrySerde.deserGeoJson(geom)));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geom", "tolerance"},
+      argTypes = {"Geometry", "double"},
+      returnTypes = "Geometry")
+  public static String ST_RemoveRepeatedPoints(String geom, double tolerance) {
+    return GeometrySerde.serGeoJson(
+        Functions.removeRepeatedPoints(GeometrySerde.deserGeoJson(geom), tolerance));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry"},
       argTypes = {"Geometry"},
@@ -1054,6 +1114,15 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.setSRID(GeometrySerde.deserGeoJson(geometry), srid));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "distanceTolerance"},
+      argTypes = {"Geometry", "double"},
+      returnTypes = "Geometry")
+  public static String ST_Simplify(String geometry, double distanceTolerance) {
+    return GeometrySerde.serGeoJson(
+        Functions.simplify(GeometrySerde.deserGeoJson(geometry), distanceTolerance));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry", "distanceTolerance"},
       argTypes = {"Geometry", "double"},
@@ -1490,6 +1559,37 @@ public class UDFsV2 {
         Functions.translate(GeometrySerde.deserGeoJson(geom), deltaX, deltaY, deltaZ));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "scaleX", "scaleY"},
+      argTypes = {"Geometry", "double", "double"},
+      returnTypes = "Geometry")
+  public static String ST_Scale(String geometry, double scaleX, double scaleY) {
+    return GeometrySerde.serGeoJson(
+        Functions.scale(GeometrySerde.deserGeoJson(geometry), scaleX, scaleY));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "factor", "origin"},
+      argTypes = {"Geometry", "Geometry", "Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_ScaleGeom(String geometry, String factor, String origin) {
+    return GeometrySerde.serGeoJson(
+        Functions.scaleGeom(
+            GeometrySerde.deserGeoJson(geometry),
+            GeometrySerde.deserGeoJson(factor),
+            GeometrySerde.deserGeoJson(origin)));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "factor"},
+      argTypes = {"Geometry", "Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_ScaleGeom(String geometry, String factor) {
+    return GeometrySerde.serGeoJson(
+        Functions.scaleGeom(
+            GeometrySerde.deserGeoJson(geometry), GeometrySerde.deserGeoJson(factor)));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry", "angle"},
       argTypes = {"Geometry", "double"},
@@ -1498,6 +1598,14 @@ public class UDFsV2 {
     return GeometrySerde.serGeoJson(Functions.rotateX(GeometrySerde.deserGeoJson(geometry), angle));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "angle"},
+      argTypes = {"Geometry", "double"},
+      returnTypes = "Geometry")
+  public static String ST_RotateY(String geometry, double angle) {
+    return GeometrySerde.serGeoJson(Functions.rotateY(GeometrySerde.deserGeoJson(geometry), angle));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geom", "angle"},
       argTypes = {"Geometry", "double"},
