@@ -23,7 +23,7 @@ import java.lang.reflect.Field;
 import org.apache.sedona.core.enums.GridType;
 import org.apache.sedona.core.enums.IndexType;
 import org.apache.sedona.core.enums.JoinBuildSide;
-import org.apache.sedona.core.enums.JoinSparitionDominantSide;
+import org.apache.sedona.core.enums.JoinSpartitionDominantSide;
 import org.apache.sedona.core.enums.SpatialJoinOptimizationMode;
 import org.apache.spark.sql.RuntimeConfig;
 import org.apache.spark.sql.SparkSession;
@@ -40,7 +40,7 @@ public class SedonaConf implements Serializable {
 
   // Parameters for JoinQuery including RangeJoin and DistanceJoin
 
-  private JoinSparitionDominantSide joinSparitionDominantSide;
+  private JoinSpartitionDominantSide joinSpartitionDominantSide;
 
   private JoinBuildSide joinBuildSide;
 
@@ -56,38 +56,61 @@ public class SedonaConf implements Serializable {
 
   private SpatialJoinOptimizationMode spatialJoinOptimizationMode;
 
+  // Parameters for knn joins
+  private boolean includeTieBreakersInKNNJoins = false;
+
   public static SedonaConf fromActiveSession() {
     return new SedonaConf(SparkSession.active().conf());
   }
 
   public SedonaConf(RuntimeConfig runtimeConfig) {
-    this.useIndex = Boolean.parseBoolean(runtimeConfig.get("sedona.global.index", "true"));
-    this.indexType = IndexType.getIndexType(runtimeConfig.get("sedona.global.indextype", "rtree"));
+    this.useIndex = Boolean.parseBoolean(getConfigValue(runtimeConfig, "global.index", "true"));
+    this.indexType =
+        IndexType.getIndexType(getConfigValue(runtimeConfig, "global.indextype", "rtree"));
     this.joinApproximateTotalCount =
-        Long.parseLong(runtimeConfig.get("sedona.join.approxcount", "-1"));
-    String[] boundaryString = runtimeConfig.get("sedona.join.boundary", "0,0,0,0").split(",");
+        Long.parseLong(getConfigValue(runtimeConfig, "join.approxcount", "-1"));
+    String[] boundaryString = getConfigValue(runtimeConfig, "join.boundary", "0,0,0,0").split(",");
     this.datasetBoundary =
         new Envelope(
             Double.parseDouble(boundaryString[0]),
             Double.parseDouble(boundaryString[1]),
             Double.parseDouble(boundaryString[2]),
             Double.parseDouble(boundaryString[3]));
-    this.joinGridType = GridType.getGridType(runtimeConfig.get("sedona.join.gridtype", "kdbtree"));
+    this.joinGridType =
+        GridType.getGridType(getConfigValue(runtimeConfig, "join.gridtype", "kdbtree"));
     this.joinBuildSide =
-        JoinBuildSide.getBuildSide(runtimeConfig.get("sedona.join.indexbuildside", "left"));
-    this.joinSparitionDominantSide =
-        JoinSparitionDominantSide.getJoinSparitionDominantSide(
-            runtimeConfig.get("sedona.join.spatitionside", "left"));
+        JoinBuildSide.getBuildSide(getConfigValue(runtimeConfig, "join.indexbuildside", "left"));
+    this.joinSpartitionDominantSide =
+        JoinSpartitionDominantSide.getJoinSpartitionDominantSide(
+            getConfigValue(runtimeConfig, "join.spatitionside", "left"));
     this.fallbackPartitionNum =
-        Integer.parseInt(runtimeConfig.get("sedona.join.numpartition", "-1"));
+        Integer.parseInt(getConfigValue(runtimeConfig, "join.numpartition", "-1"));
     this.autoBroadcastJoinThreshold =
         bytesFromString(
-            runtimeConfig.get(
-                "sedona.join.autoBroadcastJoinThreshold",
+            getConfigValue(
+                runtimeConfig,
+                "join.autoBroadcastJoinThreshold",
                 runtimeConfig.get("spark.sql.autoBroadcastJoinThreshold")));
     this.spatialJoinOptimizationMode =
         SpatialJoinOptimizationMode.getSpatialJoinOptimizationMode(
-            runtimeConfig.get("sedona.join.optimizationmode", "nonequi"));
+            getConfigValue(runtimeConfig, "join.optimizationmode", "nonequi"));
+
+    // Parameters for knn joins
+    this.includeTieBreakersInKNNJoins =
+        Boolean.parseBoolean(getConfigValue(runtimeConfig, "join.knn.includeTieBreakers", "false"));
+  }
+
+  // Helper method to prioritize `sedona.*` over `spark.sedona.*`
+  private String getConfigValue(
+      RuntimeConfig runtimeConfig, String keySuffix, String defaultValue) {
+    String sedonaKey = "sedona." + keySuffix;
+    String sparkSedonaKey = "spark.sedona." + keySuffix;
+
+    if (runtimeConfig.contains(sedonaKey)) {
+      return runtimeConfig.get(sedonaKey, defaultValue);
+    } else {
+      return runtimeConfig.get(sparkSedonaKey, defaultValue);
+    }
   }
 
   public boolean getUseIndex() {
@@ -114,8 +137,8 @@ public class SedonaConf implements Serializable {
     return joinGridType;
   }
 
-  public JoinSparitionDominantSide getJoinSparitionDominantSide() {
-    return joinSparitionDominantSide;
+  public JoinSpartitionDominantSide getJoinSpartitionDominantSide() {
+    return joinSpartitionDominantSide;
   }
 
   public int getFallbackPartitionNum() {
@@ -126,6 +149,10 @@ public class SedonaConf implements Serializable {
     return autoBroadcastJoinThreshold;
   }
 
+  public boolean isIncludeTieBreakersInKNNJoins() {
+    return includeTieBreakersInKNNJoins;
+  }
+
   public String toString() {
     try {
       String sb = "";
