@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.sedona.python.wrapper.translation
 
 import org.apache.sedona.common.geometryObjects.Circle
@@ -27,7 +26,9 @@ import org.locationtech.jts.geom.Geometry
 import java.io.{ByteArrayInputStream, DataInputStream}
 import java.nio.{ByteBuffer, ByteOrder}
 
-case class PythonRDDToJavaConverter(javaRDD: JavaRDD[Array[Byte]], geometrySerializer: PythonGeometrySerializer) {
+case class PythonRDDToJavaConverter(
+    javaRDD: JavaRDD[Array[Byte]],
+    geometrySerializer: PythonGeometrySerializer) {
   def translateToJava: JavaRDD[Geometry] = {
     javaRDD.rdd.map[Geometry](serializedGeoData => {
       val geoDataBytes = new ByteArrayInputStream(serializedGeoData)
@@ -37,17 +38,22 @@ case class PythonRDDToJavaConverter(javaRDD: JavaRDD[Array[Byte]], geometrySeria
     })
   }
 
-  private def readGeometry(serializedGeoData: Array[Byte], inputStream: DataInputStream): Geometry = {
+  private def readGeometry(
+      serializedGeoData: Array[Byte],
+      inputStream: DataInputStream): Geometry = {
     val isCircle = inputStream.readByte().toInt
     val geomDataLength = java.lang.Integer.reverseBytes(inputStream.readInt())
     val userDataLength = java.lang.Integer.reverseBytes(inputStream.readInt())
-    val skipBytes = 13  // 4 bytes for rddType, 1 byte for isCircle, 4 bytes for geomDataLength, 4 bytes for userDataLength
+    val skipBytes =
+      13 // 4 bytes for rddType, 1 byte for isCircle, 4 bytes for geomDataLength, 4 bytes for userDataLength
 
     // Circle will be handled specially in the next step. We don't let geometrySerializer.deserialize handle Circle
     // for us since this serialization format is a little bit different from the one used in PythonGeometrySerializer.
     val geom = geometrySerializer.deserialize(0, serializedGeoData, skipBytes)
-    val userData = serializedGeoData.slice(skipBytes + geomDataLength, skipBytes + geomDataLength + userDataLength)
-      .map(_.toChar).mkString
+    val userData = serializedGeoData
+      .slice(skipBytes + geomDataLength, skipBytes + geomDataLength + userDataLength)
+      .map(_.toChar)
+      .mkString
 
     val finalGeom = if (isCircle == 1) {
       val radiusOffset = skipBytes + geomDataLength + userDataLength
