@@ -22,7 +22,7 @@ import org.apache.spark.sql.catalyst.FunctionIdentifier
 import org.apache.spark.sql.catalyst.analysis.FunctionRegistry.FunctionBuilder
 import org.apache.spark.sql.catalyst.expressions.{ExpectsInputTypes, Expression, ExpressionInfo, Literal}
 import org.apache.spark.sql.expressions.Aggregator
-import org.apache.spark.sql.sedona_sql.expressions._
+import org.apache.spark.sql.sedona_sql.expressions.{ST_InterpolatePoint, _}
 import org.apache.spark.sql.sedona_sql.expressions.collect.ST_Collect
 import org.apache.spark.sql.sedona_sql.expressions.raster._
 import org.locationtech.jts.geom.Geometry
@@ -55,17 +55,21 @@ object Catalog {
     function[ST_GeomFromGML](),
     function[ST_GeomFromKML](),
     function[ST_CoordDim](),
+    function[ST_Perimeter](),
     function[ST_Point](),
     function[ST_Points](),
+    function[ST_MakeEnvelope](),
     function[ST_MakePoint](null, null),
     function[ST_MakePointM](),
     function[ST_PointZ](0),
     function[ST_PointM](0),
     function[ST_PointZM](0),
     function[ST_PolygonFromEnvelope](),
+    function[ST_Project](),
     function[ST_Contains](),
     function[ST_Intersects](),
     function[ST_Within](),
+    function[ST_KNN](),
     function[ST_Covers](),
     function[ST_CoveredBy](),
     function[ST_Dimension](),
@@ -113,6 +117,7 @@ object Catalog {
     function[ST_AsHEXEWKB](),
     function[ST_AsGML](),
     function[ST_AsKML](),
+    function[ST_Simplify](),
     function[ST_SimplifyVW](),
     function[ST_SimplifyPolygonHull](),
     function[ST_SRID](),
@@ -146,6 +151,7 @@ object Catalog {
     function[ST_H3ToGeom](),
     function[ST_H3KRing](),
     function[ST_InteriorRingN](),
+    function[ST_InterpolatePoint](),
     function[ST_Dump](),
     function[ST_DumpPoints](),
     function[ST_IsClosed](),
@@ -155,6 +161,7 @@ object Catalog {
     function[ST_AddMeasure](),
     function[ST_AddPoint](-1),
     function[ST_RemovePoint](-1),
+    function[ST_RemoveRepeatedPoints](),
     function[ST_SetPoint](),
     function[ST_IsPolygonCW](),
     function[ST_IsRing](),
@@ -229,8 +236,11 @@ object Catalog {
     function[ST_HausdorffDistance](-1),
     function[ST_DWithin](),
     function[ST_IsValidReason](),
+    function[ST_Scale](),
+    function[ST_ScaleGeom](),
     function[ST_Rotate](),
     function[ST_RotateX](),
+    function[ST_RotateY](),
     // Expression for rasters
     function[RS_NormalizedDifference](),
     function[RS_Mean](),
