@@ -442,6 +442,14 @@ case class ST_ReducePrecision(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_Simplify(inputExpressions: Seq[Expression])
+    extends InferredExpression(Functions.simplify _) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 case class ST_SimplifyVW(inputExpressions: Seq[Expression])
     extends InferredExpression(Functions.simplifyVW _) {
 
@@ -851,6 +859,16 @@ case class ST_RemovePoint(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_RemoveRepeatedPoints(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction2(Functions.removeRepeatedPoints),
+      inferrableFunction1(Functions.removeRepeatedPoints)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 case class ST_SetPoint(inputExpressions: Seq[Expression])
     extends InferredExpression(Functions.setPoint _) {
 
@@ -975,6 +993,17 @@ case class ST_MakeLine(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_Perimeter(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction3(Functions.perimeter),
+      inferrableFunction2(Functions.perimeter),
+      inferrableFunction1(Functions.perimeter)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 case class ST_Points(inputExpressions: Seq[Expression])
     extends InferredExpression(Functions.points _) {
 
@@ -999,6 +1028,16 @@ case class ST_Polygonize(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_Project(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction4(Functions.project),
+      inferrableFunction3(Functions.project)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 case class ST_MakePolygon(inputExpressions: Seq[Expression])
     extends InferredExpression(InferrableFunction.allowRightNull(Functions.makePolygon)) {
 
@@ -1698,6 +1737,22 @@ case class ST_IsValidReason(inputExpressions: Seq[Expression])
     copy(inputExpressions = newChildren)
 }
 
+case class ST_Scale(inputExpressions: Seq[Expression])
+    extends InferredExpression(inferrableFunction3(Functions.scale)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) =
+    copy(inputExpressions = newChildren)
+}
+
+case class ST_ScaleGeom(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction3(Functions.scaleGeom),
+      inferrableFunction2(Functions.scaleGeom)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) =
+    copy(inputExpressions = newChildren)
+}
+
 case class ST_RotateX(inputExpressions: Seq[Expression])
     extends InferredExpression(inferrableFunction2(Functions.rotateX)) {
 
@@ -1705,6 +1760,13 @@ case class ST_RotateX(inputExpressions: Seq[Expression])
     copy(inputExpressions = newChildren)
 }
 
+case class ST_RotateY(inputExpressions: Seq[Expression])
+    extends InferredExpression(inferrableFunction2(Functions.rotateY)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) =
+    copy(inputExpressions = newChildren)
+}
+
 case class ST_Rotate(inputExpressions: Seq[Expression])
     extends InferredExpression(
       inferrableFunction2(Functions.rotate),
@@ -1714,3 +1776,9 @@ case class ST_Rotate(inputExpressions: Seq[Expression])
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) =
     copy(inputExpressions = newChildren)
 }
+
+case class ST_InterpolatePoint(inputExpressions: Seq[Expression])
+    extends InferredExpression(inferrableFunction2(Functions.interpolatePoint)) {
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) =
+    copy(inputExpressions = newChildren)
+}
