@@ -358,6 +358,17 @@ object st_functions extends DataFrameAPI {
   def ST_MakeLine(geom1: String, geom2: String): Column =
     wrapExpression[ST_MakeLine](geom1, geom2)
 
+  def ST_Perimeter(geom: Column): Column = wrapExpression[ST_Perimeter](geom)
+  def ST_Perimeter(geom: String): Column = wrapExpression[ST_Perimeter](geom)
+  def ST_Perimeter(geom: Column, use_spheroid: Column): Column =
+    wrapExpression[ST_Perimeter](geom, use_spheroid)
+  def ST_Perimeter(geom: String, use_spheroid: Boolean): Column =
+    wrapExpression[ST_Perimeter](geom, use_spheroid)
+  def ST_Perimeter(geom: Column, use_spheroid: Column, lenient: Column): Column =
+    wrapExpression[ST_Perimeter](geom, use_spheroid, lenient)
+  def ST_Perimeter(geom: String, use_spheroid: Boolean, lenient: Boolean): Column =
+    wrapExpression[ST_Perimeter](geom, use_spheroid, lenient)
+
   def ST_Points(geom: Column): Column = wrapExpression[ST_Points](geom)
   def ST_Points(geom: String): Column = wrapExpression[ST_Points](geom)
 
@@ -369,6 +380,19 @@ object st_functions extends DataFrameAPI {
   def ST_Polygonize(geoms: Column): Column = wrapExpression[ST_Polygonize](geoms)
   def ST_Polygonize(geoms: String): Column = wrapExpression[ST_Polygonize](geoms)
 
+  def ST_Project(point: Column, distance: Column, azimuth: Column, lenient: Column): Column =
+    wrapExpression[ST_Project](point, distance, azimuth, lenient)
+  def ST_Project(point: String, distance: String, azimuth: String, lenient: String): Column =
+    wrapExpression[ST_Project](point, distance, azimuth, lenient)
+  def ST_Project(point: String, distance: Double, azimuth: Double, lenient: Boolean): Column =
+    wrapExpression[ST_Project](point, distance, azimuth, lenient)
+  def ST_Project(point: Column, distance: Column, azimuth: Column): Column =
+    wrapExpression[ST_Project](point, distance, azimuth)
+  def ST_Project(point: String, distance: String, azimuth: String): Column =
+    wrapExpression[ST_Project](point, distance, azimuth)
+  def ST_Project(point: String, distance: Double, azimuth: Double): Column =
+    wrapExpression[ST_Project](point, distance, azimuth)
+
   def ST_MakePolygon(lineString: Column): Column =
     wrapExpression[ST_MakePolygon](lineString, null)
   def ST_MakePolygon(lineString: String): Column =
@@ -468,9 +492,38 @@ object st_functions extends DataFrameAPI {
   def ST_RemovePoint(lineString: String, index: Int): Column =
     wrapExpression[ST_RemovePoint](lineString, index)
 
+  def ST_RemoveRepeatedPoints(geom: Column, tolerance: Column): Column =
+    wrapExpression[ST_RemoveRepeatedPoints](geom, tolerance)
+  def ST_RemoveRepeatedPoints(geom: String, tolerance: Double): Column =
+    wrapExpression[ST_RemoveRepeatedPoints](geom, tolerance)
+  def ST_RemoveRepeatedPoints(geom: String, tolerance: String): Column =
+    wrapExpression[ST_RemoveRepeatedPoints](geom, tolerance)
+
+  def ST_RemoveRepeatedPoints(geom: Column): Column =
+    wrapExpression[ST_RemoveRepeatedPoints](geom)
+  def ST_RemoveRepeatedPoints(geom: String): Column =
+    wrapExpression[ST_RemoveRepeatedPoints](geom)
+
   def ST_Reverse(geometry: Column): Column = wrapExpression[ST_Reverse](geometry)
   def ST_Reverse(geometry: String): Column = wrapExpression[ST_Reverse](geometry)
 
+  def ST_Scale(geometry: Column, scaleX: Column, scaleY: Column): Column =
+    wrapExpression[ST_Scale](geometry, scaleX, scaleY)
+  def ST_Scale(geometry: String, scaleX: Double, scaleY: Double): Column =
+    wrapExpression[ST_Scale](geometry, scaleX, scaleY)
+  def ST_Scale(geometry: String, scaleX: String, scaleY: String): Column =
+    wrapExpression[ST_Scale](geometry, scaleX, scaleY)
+
+  def ST_ScaleGeom(geometry: Column, factor: Column): Column =
+    wrapExpression[ST_ScaleGeom](geometry, factor)
+  def ST_ScaleGeom(geometry: String, factor: String): Column =
+    wrapExpression[ST_ScaleGeom](geometry, factor)
+
+  def ST_ScaleGeom(geometry: Column, factor: Column, origin: Column): Column =
+    wrapExpression[ST_ScaleGeom](geometry, factor, origin)
+  def ST_ScaleGeom(geometry: String, factor: String, origin: String): Column =
+    wrapExpression[ST_ScaleGeom](geometry, factor, origin)
+
   def ST_RotateX(geometry: Column, angle: Column): Column =
     wrapExpression[ST_RotateX](geometry, angle)
   def ST_RotateX(geometry: String, angle: Double): Column =
@@ -478,6 +531,13 @@ object st_functions extends DataFrameAPI {
   def ST_RotateX(geometry: String, angle: String): Column =
     wrapExpression[ST_RotateX](geometry, angle)
 
+  def ST_RotateY(geometry: Column, angle: Column): Column =
+    wrapExpression[ST_RotateY](geometry, angle)
+  def ST_RotateY(geometry: String, angle: Double): Column =
+    wrapExpression[ST_RotateY](geometry, angle)
+  def ST_RotateY(geometry: String, angle: String): Column =
+    wrapExpression[ST_RotateY](geometry, angle)
+
   def ST_Rotate(geometry: Column, angle: Column): Column =
     wrapExpression[ST_Rotate](geometry, angle)
   def ST_Rotate(geometry: String, angle: Double): Column =
@@ -564,6 +624,11 @@ object st_functions extends DataFrameAPI {
   def ST_Transform(geometry: Column, targetCRS: Column): Column =
     wrapExpression[ST_Transform](geometry, targetCRS)
 
+  def ST_Simplify(geometry: Column, distanceTolerance: Column): Column =
+    wrapExpression[ST_Simplify](geometry, distanceTolerance)
+  def ST_Simplify(geometry: String, distanceTolerance: Double): Column =
+    wrapExpression[ST_Simplify](geometry, distanceTolerance)
+
   def ST_SimplifyVW(geometry: Column, distanceTolerance: Column): Column =
     wrapExpression[ST_SimplifyVW](geometry, distanceTolerance)
   def ST_SimplifyVW(geometry: String, distanceTolerance: Double): Column =
@@ -856,13 +921,13 @@ object st_functions extends DataFrameAPI {
     wrapExpression[ST_HausdorffDistance](g1, g2, -1)
 
   def ST_HausdorffDistance(g1: String, g2: String) =
-    wrapExpression[ST_HausdorffDistance](g1, g2, -1);
+    wrapExpression[ST_HausdorffDistance](g1, g2, -1)
 
   def ST_HausdorffDistance(g1: Column, g2: Column, densityFrac: Column) =
-    wrapExpression[ST_HausdorffDistance](g1, g2, densityFrac);
+    wrapExpression[ST_HausdorffDistance](g1, g2, densityFrac)
 
   def ST_HausdorffDistance(g1: String, g2: String, densityFrac: Double) =
-    wrapExpression[ST_HausdorffDistance](g1, g2, densityFrac);
+    wrapExpression[ST_HausdorffDistance](g1, g2, densityFrac)
 
   def ST_CoordDim(geometry: Column): Column = wrapExpression[ST_CoordDim](geometry)
 
@@ -872,4 +937,10 @@ object st_functions extends DataFrameAPI {
 
   def ST_IsCollection(geometry: String): Column = wrapExpression[ST_IsCollection](geometry)
 
+  def ST_InterpolatePoint(geom1: Column, geom2: Column): Column =
+    wrapExpression[ST_InterpolatePoint](geom1, geom2)
+
+  def ST_InterpolatePoint(geom1: String, geom2: String): Column =
+    wrapExpression[ST_InterpolatePoint](geom1, geom2)
+
 }
