@@ -19,10 +19,7 @@
 package org.apache.sedona.core.spatialOperator;
 
 import java.io.IOException;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
+import java.util.*;
 import java.util.stream.Collectors;
 import org.apache.sedona.core.enums.GridType;
 import org.apache.sedona.core.enums.IndexType;
@@ -53,7 +50,9 @@ public class JoinQueryTest extends SpatialQueryTestBase {
 
   @Parameterized.Parameters(name = "JoinQueryTest-{index}: {0}")
   public static SpatialPredicate[] spatialPredicates() {
-    return SpatialPredicate.values();
+    return Arrays.stream(SpatialPredicate.values())
+        .filter(predicate -> predicate != SpatialPredicate.KNN)
+        .toArray(SpatialPredicate[]::new);
   }
 
   private final SpatialPredicate spatialPredicate;
