@@ -29,9 +29,11 @@ import org.apache.sedona.spark.SedonaContext
 import org.apache.spark.SparkContext
 import org.apache.spark.sql.{DataFrame, SparkSession}
 import org.locationtech.jts.geom._
+import org.locationtech.jts.io.WKTReader
 import org.scalatest.{BeforeAndAfterAll, FunSpec}
 
 import java.io.File
+import java.nio.file.Files
 
 trait TestBaseScala extends FunSpec with BeforeAndAfterAll {
   Logger.getRootLogger.setLevel(Level.WARN)
@@ -97,6 +99,7 @@ trait TestBaseScala extends FunSpec with BeforeAndAfterAll {
   override def beforeAll(): Unit = {
     super.beforeAll()
     SedonaContext.create(sparkSession)
+    sc.setCheckpointDir(Files.createTempDirectory("checkpoints").toString)
   }
 
   override def afterAll(): Unit = {
@@ -316,4 +319,49 @@ trait TestBaseScala extends FunSpec with BeforeAndAfterAll {
     val hdfsCluster = builder.build
     (hdfsCluster, "hdfs://127.0.0.1:" + hdfsCluster.getNameNodePort + "/")
   }
+
+  protected def assertDataFramesEqual(df1: DataFrame, df2: DataFrame): Unit = {
+    val dfDiff1 = df1.except(df2)
+    val dfDiff2 = df2.except(df1)
+
+    assert(dfDiff1.isEmpty && dfDiff2.isEmpty)
+  }
+
+  def assertGeometryEquals(expectedWkt: String, actualWkt: String, tolerance: Double): Unit = {
+    val reader = new WKTReader
+    val expectedGeom = reader.read(expectedWkt)
+    val actualGeom = reader.read(actualWkt)
+    assertGeometryEquals(expectedGeom, actualGeom, tolerance)
+  }
+
+  def assertGeometryEquals(expectedWkt: String, actualGeom: Geometry, tolerance: Double): Unit = {
+    val reader = new WKTReader
+    val expectedGeom = reader.read(expectedWkt)
+    assertGeometryEquals(expectedGeom, actualGeom, tolerance)
+  }
+
+  def assertGeometryEquals(
+      expectedGeom: Geometry,
+      actualGeom: Geometry,
+      tolerance: Double): Unit = {
+    if (!(expectedGeom == actualGeom)) {
+      if (!expectedGeom
+          .buffer(tolerance)
+          .contains(actualGeom) || !actualGeom.buffer(tolerance).contains(expectedGeom)) {
+        fail(String.format("Geometry %s should equal to %s", actualGeom, expectedGeom))
+      }
+    }
+  }
+
+  def assertGeometryEquals(expectedGeom: Geometry, actualGeom: Geometry): Unit = {
+    assertGeometryEquals(expectedGeom, actualGeom, 1e-6)
+  }
+
+  def assertGeometryEquals(expectedWkt: String, actualWkt: String): Unit = {
+    assertGeometryEquals(expectedWkt, actualWkt, 1e-6)
+  }
+
+  def assertGeometryEquals(expectedWkt: String, actualGeom: Geometry): Unit = {
+    assertGeometryEquals(expectedWkt, actualGeom, 1e-6)
+  }
 }
